<?php
/*
Plugin Name: INFINITO - Custom CSS for Chosen Pages and Posts or for Entire Website
Description: This plugin will allow you to add custom CSS for your entire website or only for chosen pages or posts
Version: 1.0
Author: 20script
Author URI: https://www.20script.ir
*/

ini_set('display_errors', 0);
$lbg_infinito_custom_css_path = trailingslashit(dirname(__FILE__));  //empty

//all the messages
$lbg_infinito_custom_css_messages = array(
		'version' => '<div class="error">INFINITO - Custom CSS for Chosen Pages and Posts or for Entire Website plugin requires WordPress 3.0 or newer. <a href="https://codex.wordpress.org/Upgrading_WordPress">Please update!</a></div>',
		'data_saved' => 'Data Saved!',
		'invalid_request' => 'Invalid Request!',
		'duplicate_complete' => 'Duplication process is complete!'
	);


global $wp_version;

if ( !version_compare($wp_version,"3.0",">=")) {
	die ($lbg_infinito_custom_css_messages['version']);
}




function lbg_infinito_custom_css_activate() {
	//db creation, create admin options etc.
	global $wpdb;

	$lbg_infinito_custom_css_collate = ' COLLATE utf8_general_ci';


	$sql0 = "CREATE TABLE `" . $wpdb->prefix . "lbg_infinito_custom_css` (
  `id` smallint(5) unsigned NOT NULL AUTO_INCREMENT,
  `css_def` text,
	`page_id` BIGINT unsigned NOT NULL DEFAULT '0',
	  PRIMARY KEY  (`id`)
	) ENGINE=MyISAM  DEFAULT CHARSET=utf8";



	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql0.$lbg_infinito_custom_css_collate);


	// initialize the general css def
	$rows_count = $wpdb->get_var( "SELECT COUNT(*) FROM ". $wpdb->prefix ."lbg_infinito_custom_css;" );
	if (!$rows_count) {
		lbg_infinito_custom_css_insert_settings_record(1);
	}




}


function lbg_infinito_custom_css_uninstall() {
	global $wpdb;
	$sql = "DROP TABLE IF EXISTS `" . $wpdb->prefix . "lbg_infinito_custom_css`";
	$wpdb->query($sql);
}

function lbg_infinito_custom_css_insert_settings_record($player_id) {
	global $wpdb;
	$wpdb->insert(
			$wpdb->prefix . "lbg_infinito_custom_css",
			array(
				'css_def' => '/*  Add the custom css for your entire website here  */',
				'page_id' => 0
			),
			array(
				'%s',
				'%d'
			)
		);
}



function lbg_infinito_custom_css_load_styles() {
	if(strpos($_SERVER['PHP_SELF'], 'wp-admin') !== false) { //loads css in admin
			$page = (isset($_GET['page'])) ? $_GET['page'] : '';
			if(preg_match('/lbg_infinito_custom_css/i', $page)) {
				wp_enqueue_style('lbg_infinito_custom_css_admin_file', plugins_url('css/styles.css', __FILE__));
			}
	} else if (!is_admin()) { //loads css in front-end
			wp_enqueue_style('lbg_infinito_custom_css_general_css', plugins_url('tpl/infinito_general_definitions.css?d='.time(), __FILE__));
	}
}



function lbg_infinito_custom_css_add_meta_box() {

	$screens = array( 'post', 'page' );

	foreach ( $screens as $screen ) {

		add_meta_box(
			'lbg_infinito_custom_css_sectionid',
			__( 'INFINITO - Add Here Your Custom CSS, Only For This Page:', 'lbg_infinito_custom_css_textdomain' ),
			'lbg_infinito_custom_css_meta_box_callback',
			$screen
		);
	}
}
add_action( 'add_meta_boxes', 'lbg_infinito_custom_css_add_meta_box' );


// adds the menu pages
function lbg_infinito_custom_css_plugin_menu() {
	add_menu_page('INFINITO CUSTOM CSS Admin Interface', 'INFINITO CUSTOM CSS', 'edit_posts', 'lbg_infinito_custom_css', 'lbg_infinito_custom_css_entire_website_page',
	plugins_url('images/infinito_custom_css_icon.png', __FILE__));
	add_submenu_page( 'lbg_infinito_custom_css', 'INFINITO CUSTOM CSS Entire Website', 'Edit The Custom CSS For Entire Website', 'edit_posts', 'lbg_infinito_custom_css', 'lbg_infinito_custom_css_entire_website_page');
	add_submenu_page( 'lbg_infinito_custom_css', 'INFINITO CUSTOM CSS Help', 'Help', 'edit_posts', 'lbg_infinito_custom_css_Help', 'lbg_infinito_custom_css_player_help_page');
}


/**
 * Prints the box content.
 *
 * @param WP_Post $post The object for the current post/page.
 */
function lbg_infinito_custom_css_meta_box_callback( $post ) {

	// Add an nonce field so we can check for it later.
	wp_nonce_field( 'lbg_infinito_custom_css_meta_box', 'lbg_infinito_custom_css_meta_box_nonce' );

	/*
	 * Use get_post_meta() to retrieve an existing value
	 * from the database and use the value for the form.
	 */
	$value = get_post_meta( $post->ID, '_my_meta_value_key_css_def', true );

	/*echo '<label for="lbg_infinito_custom_css_only_for_page">';
	_e( 'INFINITO - Add Here The Custom CSS Only For This Page: ', 'lbg_infinito_custom_css_textdomain' );
	echo '</label> ';*/
	echo '<textarea rows="10" name="lbg_infinito_custom_css_only_for_page" id="lbg_infinito_custom_css_only_for_page" style="width: 100%;">'. esc_attr( $value ) .'</textarea>';
	//echo '<input type="text" id="lbg_infinito_custom_css_only_for_page" name="lbg_infinito_custom_css_only_for_page" value="' . esc_attr( $value ) . '" size="50" />';
}


/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id The ID of the post being saved.
 */
function lbg_infinito_custom_css_save_meta_box_data( $post_id ) {

	/*
	 * We need to verify this came from our screen and with proper authorization,
	 * because the save_post action can be triggered at other times.
	 */

	// Check if our nonce is set.
	if ( ! isset( $_POST['lbg_infinito_custom_css_meta_box_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['lbg_infinito_custom_css_meta_box_nonce'], 'lbg_infinito_custom_css_meta_box' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */

	// Make sure that it is set.
	if ( ! isset( $_POST['lbg_infinito_custom_css_only_for_page'] ) ) {
		return;
	}

	// Sanitize user input.
	$my_data =  sanitize_textarea_field($_POST['lbg_infinito_custom_css_only_for_page']);

	// Update the meta field in the database.
	update_post_meta( $post_id, '_my_meta_value_key_css_def', $my_data );
}
add_action( 'save_post', 'lbg_infinito_custom_css_save_meta_box_data' );



function add_custom_css_only_for_this_page() {
	global $post;
	$my_meta = get_post_meta($post->ID,'_my_meta_value_key_css_def',TRUE);
	if ($my_meta) {
		echo '<style type="text/css">'.$my_meta.'</style>';
	}
}
add_action( 'wp_footer','add_custom_css_only_for_this_page' );






//HTML content for entire_website page
function lbg_infinito_custom_css_entire_website_page()
{
	global $wpdb;
	global $lbg_infinito_custom_css_messages;
	global $lbg_infinito_custom_css_path;

	if(array_key_exists('Submit', $_POST) && $_POST['Submit'] == 'Update Custom CSS') {
			$wpdb->update(
				$wpdb->prefix .'lbg_infinito_custom_css',
				array(
				'css_def' => $_POST['css_def']
				),
				array( 'id' => 1 )
			);
			?>
			<div id="message" class="updated"><p><?php echo $lbg_infinito_custom_css_messages['data_saved']?></p></div>
	<?php
	}


	//echo "WP_PLUGIN_URL: ".WP_PLUGIN_URL;
	$safe_sql=$wpdb->prepare( "SELECT * FROM (".$wpdb->prefix ."lbg_infinito_custom_css) WHERE id = %d",1 );
	$row = $wpdb->get_row($safe_sql,ARRAY_A);
	$row=lbg_infinito_custom_css_unstrip_array($row);
	//write the general css file start
	if(array_key_exists('Submit', $_POST) && $_POST['Submit'] == 'Update Custom CSS') {
		$filename=plugin_dir_path(__FILE__) . 'tpl/infinito_general_definitions.css';
		$fp = fopen($filename, 'w+');
		$fwrite = fwrite($fp, $row['css_def']);
	}
	//write the general css file end
	$_POST = $row;
	$_POST=lbg_infinito_custom_css_unstrip_array($_POST);




	include_once($lbg_infinito_custom_css_path . 'tpl/entire_website.php');
}






function lbg_infinito_custom_css_player_help_page()
{
	//include_once(plugins_url('tpl/help.php', __FILE__));
	global $lbg_infinito_custom_css_path;
	include_once($lbg_infinito_custom_css_path . 'tpl/help.php');
}



register_activation_hook(__FILE__,"lbg_infinito_custom_css_activate"); //activate plugin and create the database
register_uninstall_hook(__FILE__, 'lbg_infinito_custom_css_uninstall'); // on unistall delete all databases
add_action('init', 'lbg_infinito_custom_css_load_styles');	// loads required styles
add_action('admin_menu', 'lbg_infinito_custom_css_plugin_menu'); // create menus









/** OTHER FUNCTIONS **/

//stripslashes for an entire array
function lbg_infinito_custom_css_unstrip_array($array){
	if (is_array($array)) {
		foreach($array as &$val){
			if(is_array($val)){
				$val = unstrip_array($val);
			} else {
				$val = stripslashes($val);

			}
		}
	}
	return $array;
}





?>
